OC.L10N.register(
    "photos",
    {
    "Photos" : "Photos",
    "Favorites" : "Favorites",
    "Shared with you" : "Shared with you",
    "Back" : "Kembali",
    "Save" : "Simpan",
    "Remove from favorites" : "Remove from favorites",
    "Add" : "Tambah",
    "Download" : "Muat turun",
    "Delete" : "Padam",
    "Settings" : "Tetapan"
},
"nplurals=1; plural=0;");
